@@ -4,11 +4,13 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"github.com/infracost/infracost/internal/apiclient"
-	log "github.com/sirupsen/logrus"
 	"os"
 	"strconv"
 
+	log "github.com/sirupsen/logrus"
+
+	"github.com/infracost/infracost/internal/apiclient"
+
 	"github.com/open-policy-agent/opa/ast"
 	"github.com/open-policy-agent/opa/rego"
 	"github.com/spf13/cobra"
@@ -117,26 +119,29 @@ func buildCommentBody(cmd *cobra.Command, ctx *config.RunContext, paths []string
 			return nil, hasDiff, err
 		}
 
-		ctx.SetContextValue("passedPolicyCount", len(policyChecks.Passed))
-		ctx.SetContextValue("failedPolicyCount", len(policyChecks.Failures))
+		ctx.ContextValues.SetValue("passedPolicyCount", len(policyChecks.Passed))
+		ctx.ContextValues.SetValue("failedPolicyCount", len(policyChecks.Failures))
 	}
 
 	opts := output.Options{
 		DashboardEndpoint: ctx.Config.DashboardEndpoint,
 		NoColor:           ctx.Config.NoColor,
-		PolicyChecks:      policyChecks,
-		TagPolicyCheck:    tagPolicyCheck,
+		PolicyOutput:      output.NewPolicyOutput(policyChecks, tagPolicyCheck),
 		GuardrailCheck:    guardrailCheck,
 	}
 	opts.ShowAllProjects, _ = cmd.Flags().GetBool("show-all-projects")
 	opts.ShowOnlyChanges, _ = cmd.Flags().GetBool("show-changed")
 	opts.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 
-	b, err := output.ToMarkdown(combined, opts, mdOpts)
+	out, err := output.ToMarkdown(combined, opts, mdOpts)
 	if err != nil {
 		return nil, hasDiff, err
 	}
 
+	b := out.Msg
+	ctx.ContextValues.SetValue("truncated", out.OriginalMsgSize != out.RuneLen)
+	ctx.ContextValues.SetValue("originalLength", out.OriginalMsgSize)
+
 	if policyChecks.HasFailed() {
 		return b, hasDiff, policyChecks.Failures
 	}
