@@ -33,6 +33,7 @@ type QueryCLISettingsResponse struct {
 	CloudEnabled       bool `json:"cloudEnabled"`
 	ActualCostsEnabled bool `json:"actualCostsEnabled"`
 	UsageAPIEnabled    bool `json:"usageApiEnabled"`
+	TagsAPIEnabled     bool `json:"tagsApiEnabled"`
 }
 
 type runInput struct {
@@ -40,6 +41,7 @@ type runInput struct {
 	Currency       string                 `json:"currency"`
 	TimeGenerated  time.Time              `json:"timeGenerated"`
 	Metadata       map[string]interface{} `json:"metadata"`
+	TagPolicies    []output.TagPolicy     `json:"tagPolicies,omitempty"`
 }
 
 type projectResultInput struct {
@@ -74,7 +76,7 @@ func newRunInput(ctx *config.RunContext, out output.Root) (*runInput, error) {
 		}
 	}
 
-	ctxValues := ctx.ContextValues()
+	ctxValues := ctx.ContextValues.Values()
 
 	var metadata map[string]interface{}
 	b, err := json.Marshal(out.Metadata)
@@ -93,7 +95,7 @@ func newRunInput(ctx *config.RunContext, out output.Root) (*runInput, error) {
 		// Clone the map to cleanup up the "command" key to show "comment".  It is
 		// currently set to the sub comment (e.g. "github")
 		ctxValues = make(map[string]interface{}, len(ctxValues))
-		for k, v := range ctx.ContextValues() {
+		for k, v := range ctx.ContextValues.Values() {
 			ctxValues[k] = v
 		}
 		ctxValues["command"] = "comment"
@@ -104,6 +106,7 @@ func newRunInput(ctx *config.RunContext, out output.Root) (*runInput, error) {
 		Currency:       out.Currency,
 		TimeGenerated:  out.TimeGenerated.UTC(),
 		Metadata:       ctxValues,
+		TagPolicies:    out.TagPolicies,
 	}, nil
 }
 
@@ -124,6 +127,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, out output.Root) (Ad
 			addRun(run: $run) {
 				id
 				shareUrl
+				cloudUrl
 				organization {
 					id
 					name
@@ -165,6 +169,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, out output.Root) (Ad
 
 		response.RunID = cloudRun.Get("id").String()
 		response.ShareURL = cloudRun.Get("shareUrl").String()
+		response.CloudURL = cloudRun.Get("cloudUrl").String()
 		response.GuardrailCheck.TotalChecked = cloudRun.Get("guardrailsChecked").Int()
 		response.GuardrailCheck.Comment = cloudRun.Get("guardrailComment").Bool()
 		for _, event := range cloudRun.Get("guardrailEvents").Array() {
@@ -209,6 +214,7 @@ func (c *DashboardAPIClient) QueryCLISettings() (QueryCLISettingsResponse, error
             	cloudEnabled
 				actualCostsEnabled
 				usageApiEnabled
+				tagsApiEnabled
         	}
     	}
 	`
@@ -225,6 +231,7 @@ func (c *DashboardAPIClient) QueryCLISettings() (QueryCLISettingsResponse, error
 		response.CloudEnabled = results[0].Get("data.cliSettings.cloudEnabled").Bool()
 		response.ActualCostsEnabled = results[0].Get("data.cliSettings.actualCostsEnabled").Bool()
 		response.UsageAPIEnabled = results[0].Get("data.cliSettings.usageApiEnabled").Bool()
+		response.TagsAPIEnabled = results[0].Get("data.cliSettings.tagsApiEnabled").Bool()
 	}
 	return response, nil
 }
