@@ -42,6 +42,15 @@ func TestParser_Compile(t *testing.T) {
 				BaseBranch: "master",
 			},
 		},
+		{
+			name: "with rel paths",
+		},
+		{
+			name: "with list",
+		},
+		{
+			name: "with is dir",
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
