@@ -1,6 +1,8 @@
 package hcl
 
 import (
+	"crypto/sha256"
+	"encoding/hex"
 	"fmt"
 	"os"
 	"regexp"
@@ -8,7 +10,6 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/google/uuid"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/sirupsen/logrus"
@@ -248,11 +249,13 @@ type Block struct {
 	expanded bool
 	// cloneIndex represents the index of the parent that this Block has been cloned from
 	cloneIndex int
-	// parent is the block that the block was cloned from
-	parent *Block
+	// original is the block that the block was cloned from
+	original *Block
 	// childBlocks holds information about any child Blocks that the Block may have. This can be empty.
 	// See Block docs for more information about child Blocks.
 	childBlocks Blocks
+	// parent is the parent block if this is a child block.
+	parent *Block
 	// verbose determines whether the block uses verbose debug logging.
 	verbose    bool
 	logger     *logrus.Entry
@@ -272,22 +275,13 @@ type BlockBuilder struct {
 }
 
 // NewBlock returns a Block with Context and child Blocks initialised.
-func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.Block, ctx *Context, moduleBlock *Block) *Block {
+func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.Block, ctx *Context, parent *Block, moduleBlock *Block) *Block {
 	if ctx == nil {
 		ctx = NewContext(&hcl.EvalContext{}, nil, b.Logger)
 	}
 
 	isLoggingVerbose := strings.TrimSpace(os.Getenv("INFRACOST_HCL_DEBUG_VERBOSE")) == "true"
-	var children Blocks
 	if body, ok := hclBlock.Body.(*hclsyntax.Body); ok {
-		for _, bb := range body.Blocks {
-			children = append(children, b.NewBlock(filename, rootPath, bb.AsHCLBlock(), ctx, moduleBlock))
-		}
-
-		for _, f := range b.SetAttributes {
-			f(moduleBlock, hclBlock)
-		}
-
 		block := &Block{
 			Filename:    filename,
 			StartLine:   body.SrcRange.Start.Line,
@@ -296,12 +290,22 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 			hclBlock:    hclBlock,
 			moduleBlock: moduleBlock,
 			rootPath:    rootPath,
-			childBlocks: children,
+			childBlocks: make(Blocks, len(body.Blocks)),
 			verbose:     isLoggingVerbose,
 			newMock:     b.MockFunc,
+			parent:      parent,
 		}
+
 		block.setLogger(b.Logger)
 
+		for _, f := range b.SetAttributes {
+			f(block.FullName(), moduleBlock, hclBlock)
+		}
+
+		for i, bb := range body.Blocks {
+			block.childBlocks[i] = b.NewBlock(filename, rootPath, bb.AsHCLBlock(), ctx, block, moduleBlock)
+		}
+
 		return block
 	}
 
@@ -319,7 +323,6 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 			hclBlock:    hclBlock,
 			moduleBlock: moduleBlock,
 			rootPath:    rootPath,
-			childBlocks: children,
 			verbose:     isLoggingVerbose,
 			newMock:     b.MockFunc,
 		}
@@ -328,10 +331,6 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 		return block
 	}
 
-	for _, hb := range content.Blocks {
-		children = append(children, b.NewBlock(filename, rootPath, hb, ctx, moduleBlock))
-	}
-
 	block := &Block{
 		Filename:    filename,
 		StartLine:   hclBlock.DefRange.Start.Line,
@@ -340,11 +339,15 @@ func (b BlockBuilder) NewBlock(filename string, rootPath string, hclBlock *hcl.B
 		hclBlock:    hclBlock,
 		moduleBlock: moduleBlock,
 		rootPath:    rootPath,
-		childBlocks: children,
+		childBlocks: make(Blocks, len(content.Blocks)),
 		verbose:     isLoggingVerbose,
 		newMock:     b.MockFunc,
 	}
 
+	for i, hb := range content.Blocks {
+		block.childBlocks[i] = b.NewBlock(filename, rootPath, hb, ctx, block, moduleBlock)
+	}
+
 	block.setLogger(b.Logger)
 	return block
 }
@@ -361,7 +364,7 @@ func (b BlockBuilder) CloneBlock(block *Block, index cty.Value) *Block {
 
 	cloneHCL := *block.hclBlock
 
-	clone := b.NewBlock(block.Filename, block.rootPath, &cloneHCL, childCtx, block.moduleBlock)
+	clone := b.NewBlock(block.Filename, block.rootPath, &cloneHCL, childCtx, block.parent, block.moduleBlock)
 	if len(clone.hclBlock.Labels) > 0 {
 		position := len(clone.hclBlock.Labels) - 1
 		labels := make([]string, len(clone.hclBlock.Labels))
@@ -390,7 +393,7 @@ func (b BlockBuilder) CloneBlock(block *Block, index cty.Value) *Block {
 	clone.expanded = true
 	block.cloneIndex++
 
-	clone.parent = block
+	clone.original = block
 	return clone
 }
 
@@ -414,7 +417,7 @@ func (b BlockBuilder) BuildModuleBlocks(block *Block, modulePath string, rootPat
 		}
 
 		for _, fileBlock := range fileBlocks {
-			blocks = append(blocks, b.NewBlock(file.path, rootPath, fileBlock, moduleCtx, block))
+			blocks = append(blocks, b.NewBlock(file.path, rootPath, fileBlock, moduleCtx, nil, block))
 		}
 	}
 
@@ -424,50 +427,54 @@ func (b BlockBuilder) BuildModuleBlocks(block *Block, modulePath string, rootPat
 // SetAttributesFunc defines a function that sets required attributes on a hcl.Block.
 // This is done so that identifiers that are normally propagated from a Terraform state/apply
 // are set on the Block. This means they can be used properly in references and outputs.
-type SetAttributesFunc func(moduleBlock *Block, block *hcl.Block)
+type SetAttributesFunc func(address string, moduleBlock *Block, block *hcl.Block)
 
 // SetUUIDAttributes adds commonly used identifiers to the block so that it can be referenced by other
 // blocks in context evaluation. The identifiers are only set if they don't already exist as attributes
 // on the block.
-func SetUUIDAttributes(moduleBlock *Block, block *hcl.Block) {
+func SetUUIDAttributes(address string, moduleBlock *Block, block *hcl.Block) {
 	if body, ok := block.Body.(*hclsyntax.Body); ok {
 		if (block.Type == "resource" || block.Type == "data") && body.Attributes != nil {
+			h := sha256.New()
+			h.Write([]byte(address))
+			addressSha := hex.EncodeToString(h.Sum(nil))
+
 			_, withCount := body.Attributes["count"]
 			_, withEach := body.Attributes["for_each"]
 			if _, ok := body.Attributes["id"]; !ok {
-				body.Attributes["id"] = newUniqueAttribute("id", withCount, withEach)
+				body.Attributes["id"] = newUniqueAttribute(addressSha, "id", withCount, withEach)
 			}
 
 			if _, ok := body.Attributes["name"]; !ok {
-				body.Attributes["name"] = newUniqueAttribute("name", withCount, withEach)
+				body.Attributes["name"] = newUniqueAttribute(addressSha, "name", withCount, withEach)
 			}
 
 			if _, ok := body.Attributes["arn"]; !ok {
-				body.Attributes["arn"] = newArnAttribute("arn", withCount, withEach)
+				body.Attributes["arn"] = newArnAttribute(addressSha, "arn", withCount, withEach)
 			}
 
 			if _, ok := body.Attributes["self_link"]; !ok {
-				body.Attributes["self_link"] = newUniqueAttribute("self_link", withCount, withEach)
+				body.Attributes["self_link"] = newUniqueAttribute(addressSha, "self_link", withCount, withEach)
 			}
 		}
 	}
 }
 
-func newUniqueAttribute(name string, withCount bool, withEach bool) *hclsyntax.Attribute {
+func newUniqueAttribute(addressSha, name string, withCount bool, withEach bool) *hclsyntax.Attribute {
 	// prefix ids with hcl- so they can be identified as fake
 	var exp hclsyntax.Expression = &hclsyntax.LiteralValueExpr{
-		Val: cty.StringVal("hcl-" + uuid.NewString()),
+		Val: cty.StringVal("hcl-" + addressSha),
 	}
 
 	if withCount {
-		e, diags := hclsyntax.ParseExpression([]byte(`"hcl-`+uuid.NewString()+`-${count.index}"`), name, hcl.Pos{})
+		e, diags := hclsyntax.ParseExpression([]byte(`"hcl-`+addressSha+`-${count.index}"`), name, hcl.Pos{})
 		if !diags.HasErrors() {
 			exp = e
 		}
 	}
 
 	if withEach {
-		e, diags := hclsyntax.ParseExpression([]byte(`"hcl-`+uuid.NewString()+`-${each.key}"`), name, hcl.Pos{})
+		e, diags := hclsyntax.ParseExpression([]byte(`"hcl-`+addressSha+`-${each.key}"`), name, hcl.Pos{})
 		if !diags.HasErrors() {
 			exp = e
 		}
@@ -479,12 +486,13 @@ func newUniqueAttribute(name string, withCount bool, withEach bool) *hclsyntax.A
 	}
 }
 
-func newArnAttribute(name string, withCount bool, withEach bool) *hclsyntax.Attribute {
+func newArnAttribute(addressSha, name string, withCount bool, withEach bool) *hclsyntax.Attribute {
+
 	// fakeARN replicates an aws arn string it deliberately leaves the
 	// region section (in between the 3rd and 4th semicolon) blank as
 	// Infracost will try and parse this region later down the line.
 	// Keeping it blank will defer the region to what the provider has defined.
-	fakeARN := fmt.Sprintf("arn:aws:hcl::%s", uuid.NewString())
+	fakeARN := fmt.Sprintf("arn:aws:hcl::%s", addressSha)
 	var exp hclsyntax.Expression = &hclsyntax.LiteralValueExpr{
 		Val: cty.StringVal(fakeARN),
 	}
@@ -523,12 +531,12 @@ func (b *Block) InjectBlock(block *Block, name string) {
 	b.childBlocks = append(b.childBlocks, block)
 }
 
-// RemoveBlocks removes all the child Blocks of type name.
-func (b *Block) RemoveBlocks(name string) {
+// RemoveDynamicBlocks removes all the child Blocks of type name that have a parent of type "dynamic".
+func (b *Block) RemoveDynamicBlocks(name string) {
 	var filtered Blocks
 
 	for _, block := range b.childBlocks {
-		if block.Type() != name {
+		if block.Type() != name || block.parent.Type() != "dynamic" {
 			filtered = append(filtered, block)
 		}
 	}
@@ -621,9 +629,15 @@ func (b *Block) HasModuleBlock() bool {
 type ModuleMetadata struct {
 	Filename  string `json:"filename"`
 	BlockName string `json:"blockName"`
+	StartLine int    `json:"startLine,omitempty"`
+	EndLine   int    `json:"endLine,omitempty"`
 }
 
 func (b *Block) setLogger(logger *logrus.Entry) {
+	// Use the provided logger as is initially so we avoid a nil pointer in the case where we need to log
+	// an error while calculating b.FullName().
+	b.logger = logger
+
 	blockLogger := logger.WithFields(logrus.Fields{
 		"block_name": b.FullName(),
 	})
@@ -642,6 +656,8 @@ func (b *Block) CallDetails() []ModuleMetadata {
 		meta = append(meta, ModuleMetadata{
 			Filename:  block.Filename,
 			BlockName: stripCount(block.LocalName()),
+			StartLine: block.StartLine,
+			EndLine:   block.EndLine,
 		})
 
 		if block.moduleBlock == nil {
@@ -800,15 +816,23 @@ func (b *Block) GetAttributes() []*Attribute {
 	}
 
 	hclAttributes := b.getHCLAttributes()
-	var attributes = make([]*Attribute, 0, len(hclAttributes))
-	for _, attr := range hclAttributes {
+
+	// Sort the attributes so the order is deterministic
+	keys := make([]string, 0, len(hclAttributes))
+	for k := range hclAttributes {
+		keys = append(keys, k)
+	}
+	sort.Strings(keys)
+
+	var attributes = make([]*Attribute, 0, len(keys))
+	for _, k := range keys {
 		attributes = append(attributes, &Attribute{
 			newMock: b.newMock,
-			HCLAttr: attr,
+			HCLAttr: hclAttributes[k],
 			Ctx:     b.context,
 			Verbose: b.verbose,
 			Logger: b.logger.WithFields(logrus.Fields{
-				"attribute_name": attr.Name,
+				"attribute_name": hclAttributes[k].Name,
 			}),
 		})
 	}
@@ -970,7 +994,8 @@ func (b *Block) values() cty.Value {
 // out full names of Blocks to stdout or a file.
 func (b *Block) Reference() *Reference {
 	var parts []string
-	if b.Type() != "resource" {
+
+	if b.Type() != "resource" || b.parent != nil {
 		parts = append(parts, b.Type())
 	}
 
@@ -1202,9 +1227,11 @@ func getRegionFromProvider(b *Block, provider string) string {
 	attr := b.GetAttribute("provider")
 	if attr != nil {
 		v := attr.Value()
-		r := v.GetAttr("region")
-		if !r.IsNull() {
-			region = r
+		if v.Type().IsObjectType() {
+			m := v.AsValueMap()
+			if r, ok := m["region"]; ok {
+				region = r
+			}
 		}
 	}
 
