@@ -19,6 +19,7 @@ import (
 	log "github.com/sirupsen/logrus"
 
 	"github.com/infracost/infracost/internal/clierror"
+	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/schema"
 )
 
@@ -110,7 +111,7 @@ func LoadPaths(paths []string) ([]ReportInput, error) {
 // Each project in current Root will have all past resources overwritten with the matching projects
 // in the prior Root. If we can't find a matching project then we assume that the project
 // has been newly created and will show a 100% increase in the output Root.
-func CompareTo(current, prior Root) (Root, error) {
+func CompareTo(c *config.Config, current, prior Root) (Root, error) {
 	priorProjects := make(map[string]*schema.Project)
 	for _, p := range prior.Projects {
 		if _, ok := priorProjects[p.LabelWithMetadata()]; ok {
@@ -164,7 +165,7 @@ func CompareTo(current, prior Root) (Root, error) {
 
 	sort.Sort(schemaProjects)
 
-	out, err := ToOutputFormat(schemaProjects)
+	out, err := ToOutputFormat(c, schemaProjects)
 	if err != nil {
 		return out, err
 	}
@@ -199,6 +200,7 @@ func Combine(inputs []ReportInput) (Root, error) {
 
 	projects := make([]Project, 0)
 	summaries := make([]*Summary, 0, len(inputs))
+	var tagPolicies []TagPolicy
 	currency := ""
 
 	var metadata Metadata
@@ -215,6 +217,10 @@ func Combine(inputs []ReportInput) (Root, error) {
 
 		summaries = append(summaries, input.Root.Summary)
 
+		if len(input.Root.TagPolicies) > 0 {
+			tagPolicies = append(tagPolicies, input.Root.TagPolicies...)
+		}
+
 		if input.Root.TotalHourlyCost != nil {
 			if totalHourlyCost == nil {
 				totalHourlyCost = decimalPtr(decimal.Zero)
@@ -279,6 +285,7 @@ func Combine(inputs []ReportInput) (Root, error) {
 	combined.TimeGenerated = time.Now().UTC()
 	combined.Summary = MergeSummaries(summaries)
 	combined.Metadata = metadata
+	combined.TagPolicies = mergeTagPolicies(tagPolicies)
 	if len(inputs) > 0 {
 		combined.CloudURL = inputs[len(inputs)-1].Root.CloudURL
 	}
@@ -294,6 +301,30 @@ func Combine(inputs []ReportInput) (Root, error) {
 	return combined, nil
 }
 
+func mergeTagPolicies(tagPolicies []TagPolicy) []TagPolicy {
+	// gather and merge tag policies by name
+	tpMap := map[string]TagPolicy{}
+	for _, tp := range tagPolicies {
+		if existingTp, ok := tpMap[tp.Name]; ok {
+			tp.PrComment = existingTp.PrComment || tp.PrComment
+			tp.BlockPr = existingTp.BlockPr || tp.BlockPr
+			tp.Resources = append(existingTp.Resources, tp.Resources...)
+		}
+		tpMap[tp.Name] = tp
+	}
+
+	tpMerged := make([]TagPolicy, 0, len(tpMap))
+	// use the original tagPolicies array to iterate over the map so the order is preserved
+	for _, tp := range tagPolicies {
+		if mergedTp, ok := tpMap[tp.Name]; ok {
+			tpMerged = append(tpMerged, mergedTp)
+			delete(tpMap, tp.Name)
+		}
+	}
+
+	return tpMerged
+}
+
 func checkCurrency(inputCurrency, fileCurrency string) (string, error) {
 	if fileCurrency == "" {
 		fileCurrency = "USD" // default to USD
@@ -335,13 +366,17 @@ func FormatOutput(format string, r Root, opts Options) ([]byte, error) {
 	case "diff":
 		b, err = ToDiff(r, opts)
 	case "github-comment":
-		b, err = ToMarkdown(r, opts, MarkdownOptions{MaxMessageSize: GitHubMaxMessageSize})
+		out, error := ToMarkdown(r, opts, MarkdownOptions{MaxMessageSize: GitHubMaxMessageSize})
+		b, err = out.Msg, error
 	case "gitlab-comment", "azure-repos-comment":
-		b, err = ToMarkdown(r, opts, MarkdownOptions{})
+		out, error := ToMarkdown(r, opts, MarkdownOptions{})
+		b, err = out.Msg, error
 	case "bitbucket-comment":
-		b, err = ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true})
+		out, error := ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true})
+		b, err = out.Msg, error
 	case "bitbucket-comment-summary":
-		b, err = ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true, OmitDetails: true})
+		out, error := ToMarkdown(r, opts, MarkdownOptions{BasicSyntax: true, OmitDetails: true})
+		b, err = out.Msg, error
 	case "slack-message":
 		b, err = ToSlackMessage(r, opts)
 	default:
