@@ -5,7 +5,6 @@ import (
 	"strings"
 
 	"github.com/dustin/go-humanize"
-	"github.com/dustin/go-humanize/english"
 	"github.com/fatih/color"
 	"github.com/jedib0t/go-pretty/v6/table"
 	"github.com/jedib0t/go-pretty/v6/text"
@@ -24,12 +23,12 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 	s := ""
 
 	noDiffProjects := make([]string, 0)
-	erroredProjects := make([]string, 0)
+	erroredProjects := make(Projects, 0)
 
 	s += "──────────────────────────────────\n"
 	for _, project := range out.Projects {
 		if project.Metadata.HasErrors() {
-			erroredProjects = append(erroredProjects, project.LabelWithMetadata())
+			erroredProjects = append(erroredProjects, project)
 			continue
 		}
 
@@ -43,25 +42,7 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 			continue
 		}
 
-		s += fmt.Sprintf("%s %s\n",
-			ui.BoldString("Project:"),
-			project.Label(),
-		)
-
-		if project.Metadata.TerraformModulePath != "" {
-			s += fmt.Sprintf("%s %s\n",
-				ui.BoldString("Module path:"),
-				project.Metadata.TerraformModulePath,
-			)
-		}
-
-		if project.Metadata.WorkspaceLabel() != "" {
-			s += fmt.Sprintf("%s %s\n",
-				ui.BoldString("Workspace:"),
-				project.Metadata.WorkspaceLabel(),
-			)
-		}
-
+		s += projectTitle(project)
 		s += "\n"
 
 		for _, diffResource := range project.Diff.Resources {
@@ -100,6 +81,15 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 		s += "──────────────────────────────────\n"
 	}
 
+	if len(erroredProjects) > 0 {
+		for _, project := range erroredProjects {
+			s += projectTitle(project)
+			s += erroredProject(project)
+
+			s += "\n──────────────────────────────────\n"
+		}
+	}
+
 	hasDiffProjects := len(noDiffProjects)+len(erroredProjects) != len(out.Projects)
 
 	if hasDiffProjects {
@@ -108,36 +98,16 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 			opChar(ADDED),
 			opChar(REMOVED),
 		)
-		s += "\n\n"
-	}
-
-	if len(erroredProjects) > 0 {
-		s += "The following projects could not be evaluated: \n"
-		for _, project := range erroredProjects {
-			s += project + "\n"
-		}
-		s += fmt.Sprintf("Run the following command to see more details: %s", ui.PrimaryString("infracost breakdown --path=/path/to/code"))
-		s += "\n\n"
-	}
-
-	if hasDiffProjects && out.DiffTotalMonthlyCost != nil && out.DiffTotalMonthlyCost.Abs().GreaterThan(decimal.Zero) {
-		s += "──────────────────────────────────\n"
-		s += fmt.Sprintf("Infracost estimate: %s\n\n", formatCostChangeSentence(out.Currency, out.PastTotalMonthlyCost, out.TotalMonthlyCost, false))
-		s += tableForDiff(out, opts)
 		s += "\n"
 	}
 
-	if len(noDiffProjects) > 0 {
+	if len(noDiffProjects) > 0 && opts.ShowSkipped {
 		if !hasDiffProjects && len(erroredProjects) > 0 {
 			s += "──────────────────────────────────\n"
 		}
 
-		if opts.ShowSkipped {
-			s += fmt.Sprintf("The following projects have no cost estimate changes: %s", strings.Join(noDiffProjects, ", "))
-			s += fmt.Sprintf("\nRun the following command to see their breakdown: %s", ui.PrimaryString("infracost breakdown --path=/path/to/code"))
-		} else {
-			s += fmt.Sprintf("%s had no cost estimate changes, rerun with --show-skipped to see details", english.Plural(len(noDiffProjects), "project", "projects"))
-		}
+		s += fmt.Sprintf("The following projects have no cost estimate changes: %s", strings.Join(noDiffProjects, ", "))
+		s += fmt.Sprintf("\nRun the following command to see their breakdown: %s", ui.PrimaryString("infracost breakdown --path=/path/to/code"))
 
 		s += "\n\n"
 		s += "──────────────────────────────────"
@@ -149,38 +119,64 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 		s += unsupportedMsg
 	}
 
+	if hasDiffProjects && out.DiffTotalMonthlyCost != nil && out.DiffTotalMonthlyCost.Abs().GreaterThan(decimal.Zero) {
+		s += "\n\n"
+		s += fmt.Sprintf("Infracost estimate: %s\n", formatCostChangeSentence(out.Currency, out.PastTotalMonthlyCost, out.TotalMonthlyCost, false))
+		s += tableForDiff(out, opts)
+	}
+
 	return []byte(s), nil
 }
 
+func projectTitle(project Project) string {
+	s := fmt.Sprintf("%s %s\n",
+		ui.BoldString("Project:"),
+		project.Label(),
+	)
+
+	if project.Metadata.TerraformModulePath != "" {
+		s += fmt.Sprintf("%s %s\n",
+			ui.BoldString("Module path:"),
+			project.Metadata.TerraformModulePath,
+		)
+	}
+
+	if project.Metadata.WorkspaceLabel() != "" {
+		s += fmt.Sprintf("%s %s\n",
+			ui.BoldString("Workspace:"),
+			project.Metadata.WorkspaceLabel(),
+		)
+	}
+
+	return s
+}
+
 func tableForDiff(out Root, opts Options) string {
 	t := table.NewWriter()
 	t.SetStyle(table.StyleBold)
 	t.Style().Format.Header = text.FormatDefault
 	t.AppendHeader(table.Row{
 		"Project",
-		"Previous",
-		"New",
-		"Diff",
+		"Cost change",
+		"New monthly cost",
 	})
 
 	t.SetColumnConfigs([]table.ColumnConfig{
 		{Name: "Project", WidthMin: 50},
-		{Name: "Previous", WidthMin: 10, Align: text.AlignRight},
-		{Name: "New", WidthMin: 10, Align: text.AlignRight},
-		{Name: "Diff", WidthMin: 10},
+		{Name: "Cost change", WidthMin: 10, Align: text.AlignRight},
+		{Name: "New monthly cost", WidthMin: 10},
 	})
 
 	for _, project := range out.Projects {
-		if !showProject(project, opts) {
+		if !showProject(project, opts, false) {
 			continue
 		}
 
 		t.AppendRow(
 			table.Row{
 				truncateMiddle(project.Name, 64, "..."),
-				formatCost(out.Currency, project.PastBreakdown.TotalMonthlyCost),
-				formatCost(out.Currency, project.Breakdown.TotalMonthlyCost),
 				formatMarkdownCostChange(out.Currency, project.PastBreakdown.TotalMonthlyCost, project.Breakdown.TotalMonthlyCost, false),
+				formatCost(out.Currency, project.Breakdown.TotalMonthlyCost),
 			},
 		)
 
