@@ -26,11 +26,14 @@ func newComputeDisk(d *schema.ResourceData, u *schema.UsageData) *schema.Resourc
 	diskType := d.Get("type").String()
 	size := computeDiskSize(d)
 
+	iops := computeIOPS(d, diskType, size)
+
 	r := &google.ComputeDisk{
 		Address: d.Address,
 		Region:  region,
 		Type:    diskType,
 		Size:    size,
+		IOPS:    iops,
 	}
 	r.PopulateUsage(u)
 
@@ -58,6 +61,12 @@ func defaultDiskSize(diskType string) float64 {
 	if diskType == "pd-balanced" || diskType == "pd-ssd" {
 		return 100
 	}
+
+	if diskType == "pd-extreme" || diskType == "hyperdisk-extreme" {
+		return 1000
+	}
+
+	// if diskType is not specificed, default value is pd-standard
 	return 500
 }
 
@@ -88,3 +97,33 @@ func computeSnapshotDiskSize(d *schema.ResourceData) float64 {
 
 	return 0
 }
+
+func computeIOPS(d *schema.ResourceData, diskType string, diskSize float64) int64 {
+	if diskType == "pd-extreme" || diskType == "hyperdisk-extreme" {
+
+		if d.Get("provisioned_iops").Exists() {
+			return d.Get("provisioned_iops").Int()
+		}
+
+		return defaultIOPS(diskType, diskSize)
+	}
+
+	return 0
+}
+
+func defaultIOPS(diskType string, diskSize float64) int64 {
+	if diskType == "pd-extreme" {
+		return 100000
+	}
+
+	if diskType == "hyperdisk-extreme" {
+
+		if iops := diskSize * 1200; iops < 350000 {
+			return int64(iops)
+		}
+
+		return 350000
+	}
+
+	return 0
+}
