@@ -3,9 +3,10 @@ package terraform
 import (
 	"crypto/sha256"
 	"encoding/hex"
-	"encoding/json"
+	stdJson "encoding/json"
 	"flag"
 	"fmt"
+	"math/big"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -31,6 +32,8 @@ import (
 	"github.com/infracost/infracost/internal/ui"
 )
 
+var json = jsoniter.ConfigCompatibleWithStandardLibrary
+
 type HCLProvider struct {
 	scanner        *scan.TerraformPlanScanner
 	parsers        []*hcl.Parser
@@ -148,6 +151,7 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 	}
 	loader := modules.NewModuleLoader(cachePath, credsSource, ctx.RunContext.Config.TerraformSourceMap, logger, ctx.RunContext.ModuleMutex)
 	parsers, err := hcl.LoadParsers(
+		ctx,
 		initialPath,
 		loader,
 		locatorConfig,
@@ -159,7 +163,7 @@ func NewHCLProvider(ctx *config.ProjectContext, config *HCLProviderConfig, opts
 	}
 	var scanner *scan.TerraformPlanScanner
 	if runCtx.Config.PolicyAPIEndpoint != "" {
-		scanner = scan.NewTerraformPlanScanner(runCtx, ctx.Logger(), prices.GetPrices)
+		scanner = scan.NewTerraformPlanScanner(runCtx, ctx.Logger(), prices.GetPricesConcurrent)
 	}
 
 	return &HCLProvider{
@@ -224,13 +228,15 @@ func (p *HCLProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, e
 func (p *HCLProvider) parseResources(parsed HCLProject, usage schema.UsageMap) *schema.Project {
 	project := p.newProject(parsed)
 
-	partialPastResources, partialResources, err := p.planJSONParser.parseJSON(parsed.JSON, usage)
+	partialPastResources, partialResources, providerMetadatas, err := p.planJSONParser.parseJSON(parsed.JSON, usage)
 	if err != nil {
 		project.Metadata.AddErrorWithCode(err, schema.DiagJSONParsingFailure)
 
 		return project
 	}
 
+	project.AddProviderMetadata(providerMetadatas)
+
 	project.PartialPastResources = partialPastResources
 	project.PartialResources = partialResources
 
@@ -269,6 +275,10 @@ func (p *HCLProvider) newProject(parsed HCLProject) *schema.Project {
 	name := p.ctx.ProjectConfig.Name
 	if name == "" {
 		name = metadata.GenerateProjectName(p.ctx.RunContext.VCSMetadata.Remote, p.ctx.RunContext.IsCloudEnabled())
+
+		if p.ctx.RunContext.Config.ConfigFilePath == "" && parsed.Module.ModuleSuffix != "" {
+			name += "-" + parsed.Module.ModuleSuffix
+		}
 	}
 
 	return schema.NewProject(name, metadata)
@@ -374,7 +384,11 @@ func (p *HCLProvider) Modules() []HCLProject {
 			return mods[i].Module.Name < mods[j].Module.Name
 		}
 
-		return mods[i].Module.ModulePath < mods[j].Module.ModulePath
+		if mods[i].Module.ModulePath != mods[j].Module.ModulePath {
+			return mods[i].Module.ModulePath < mods[j].Module.ModulePath
+		}
+
+		return mods[i].Module.ModuleSuffix < mods[j].Module.ModuleSuffix
 	})
 
 	return mods
@@ -427,7 +441,7 @@ func (p *HCLProvider) modulesToPlanJSON(rootModule *hcl.Module) ([]byte, error)
 	p.schema.PriorState.Values.RootModule = mo.PlanModule
 	p.schema.PlannedValues.RootModule = mo.PlanModule
 
-	b, err := json.MarshalIndent(p.schema, "", "  ")
+	b, err := json.Marshal(p.schema)
 	if err != nil {
 		return nil, fmt.Errorf("error handling built plan json from hcl %w", err)
 	}
@@ -450,6 +464,11 @@ func (p *HCLProvider) marshalModule(module *hcl.Module) ModuleOut {
 		}
 	}
 
+	// sort the modules so we get deterministic output in the json
+	sort.SliceStable(module.Blocks, func(i, j int) bool {
+		return module.Blocks[i].Label() < module.Blocks[j].Label()
+	})
+
 	configResources := map[string]struct{}{}
 	for _, block := range module.Blocks {
 		if block.Type() == "resource" {
@@ -466,6 +485,11 @@ func (p *HCLProvider) marshalModule(module *hcl.Module) ModuleOut {
 		}
 	}
 
+	// sort the modules so we get deterministic output in the json
+	sort.SliceStable(module.Modules, func(i, j int) bool {
+		return module.Modules[i].Name < module.Modules[j].Name
+	})
+
 	for _, m := range module.Modules {
 		pieces := strings.Split(m.Name, ".")
 		modKey := pieces[len(pieces)-1]
@@ -582,11 +606,86 @@ func (p *HCLProvider) marshalProviderBlock(block *hcl.Block) string {
 				"constant_value": region,
 			},
 		},
+		InfracostMetadata: map[string]interface{}{
+			"filename":   block.Filename,
+			"start_line": block.StartLine,
+			"end_line":   block.EndLine,
+		},
+	}
+
+	defaultTags := p.marshalDefaultTagsBlock(block)
+	if defaultTags != nil {
+		p.schema.Configuration.ProviderConfig[name].Expressions["default_tags"] = []map[string]interface{}{defaultTags}
 	}
 
 	return name
 }
 
+func (p *HCLProvider) marshalDefaultTagsBlock(providerBlock *hcl.Block) map[string]interface{} {
+	b := providerBlock.GetChildBlock("default_tags")
+	if b == nil {
+		return nil
+	}
+
+	marshalledTags := make(map[string]interface{})
+
+	tags := b.GetAttribute("tags")
+	if tags == nil {
+		return marshalledTags
+	}
+
+	value := tags.Value()
+	if !value.IsKnown() || !value.CanIterateElements() {
+		return nil
+	}
+
+	for tag, val := range value.AsValueMap() {
+		if !val.IsKnown() {
+			p.logger.Debugf("tag %s has unknown value, cannot marshal", tag)
+			continue
+		}
+
+		if val.Type().Equals(cty.Bool) {
+			var tagValue bool
+			err := gocty.FromCtyValue(val, &tagValue)
+			if err != nil {
+				p.logger.WithError(err).Debugf("could not marshal tag %s to bool value", tag)
+				continue
+			}
+
+			marshalledTags[tag] = fmt.Sprintf("%t", tagValue)
+			continue
+		}
+
+		if val.Type() == cty.Number {
+			var tagValue big.Float
+			err := gocty.FromCtyValue(val, &tagValue)
+			if err != nil {
+				p.logger.WithError(err).Debugf("could not marshal tag %s to number value", tag)
+				continue
+			}
+
+			marshalledTags[tag] = tagValue.String()
+			continue
+		}
+
+		var tagValue string
+		err := gocty.FromCtyValue(val, &tagValue)
+		if err != nil {
+			p.logger.WithError(err).Debugf("could not marshal tag %s to string value", tag)
+			continue
+		}
+
+		marshalledTags[tag] = tagValue
+	}
+
+	return map[string]interface{}{
+		"tags": map[string]interface{}{
+			"constant_value": marshalledTags,
+		},
+	}
+}
+
 func (p *HCLProvider) countReferences(block *hcl.Block) *countExpression {
 	for _, attribute := range block.GetAttributes() {
 		name := attribute.Name()
@@ -692,7 +791,7 @@ func (p *HCLProvider) marshalBlock(block *hcl.Block, jsonValues map[string]inter
 		}
 
 		if v, ok := jsonValues[key]; ok {
-			if _, ok := v.(json.RawMessage); ok {
+			if _, ok := v.(stdJson.RawMessage); ok {
 				p.logger.WithFields(log.Fields{
 					"parent_block": block.LocalName(),
 					"child_block":  b.LocalName(),
@@ -730,7 +829,7 @@ func marshalAttributeValues(blockType string, value cty.Value) map[string]interf
 			continue
 		}
 
-		ret[key] = json.RawMessage(vJSON)
+		ret[key] = stdJson.RawMessage(vJSON)
 	}
 	return ret
 }
@@ -812,8 +911,9 @@ type ModuleOut struct {
 }
 
 type ProviderConfig struct {
-	Name        string                 `json:"name"`
-	Expressions map[string]interface{} `json:"expressions,omitempty"`
+	Name              string                 `json:"name"`
+	Expressions       map[string]interface{} `json:"expressions,omitempty"`
+	InfracostMetadata map[string]interface{} `json:"infracost_metadata"`
 }
 
 type ResourceData struct {
